#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/21 0021
# @Author  : justin.郑 3907721@qq.com
# @File    : index_baidu.py
# @Desc    : 获取百度指数
 

import matplotlib.pyplot as plt
import pandas as pd
import requests

plt.rcParams["font.sans-serif"] = ["SimHei"]


def decrypt(t: str, e: str) -> str:
    """
    解密函数
    :param t:
    :type t:
    :param e:
    :type e:
    :return:
    :rtype:
    """
    n, i, a, result = list(t), list(e), {}, []
    ln = int(len(n) / 2)
    start, end = n[ln:], n[:ln]
    a = dict(zip(end, start))
    return "".join([a[j] for j in e])


def get_ptbk(uniqid: str, cookie: str) -> str:
    headers = {
        "Accept": "application/json, text/plain, */*",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9",
        "Cache-Control": "no-cache",
        "Cookie": cookie,
        "DNT": "1",
        "Host": "zhishu.baidu.com",
        "Pragma": "no-cache",
        "Proxy-Connection": "keep-alive",
        "Referer": "zhishu.baidu.com",
        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.90 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }
    session = requests.Session()
    session.headers.update(headers)
    with session.get(
        url=f"http://index.baidu.com/Interface/ptbk?uniqid={uniqid}"
    ) as response:
        ptbk = response.json()["data"]
        return ptbk


def baidu_search_index(word, start_date, end_date, cookie):
    headers = {
        "Accept": "application/json, text/plain, */*",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9",
        "Cache-Control": "no-cache",
        "Cookie": cookie,
        "DNT": "1",
        "Host": "zhishu.baidu.com",
        "Pragma": "no-cache",
        "Proxy-Connection": "keep-alive",
        "Referer": "zhishu.baidu.com",
        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.90 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }
    session = requests.Session()
    session.headers.update(headers)
    with session.get(
        url=f"http://index.baidu.com/api/SearchApi/index?word={word}&area=0&startDate={start_date}&endDate={end_date}"
    ) as response:
        data = response.json()["data"]
        all_data = data["userIndexes"][0]["all"]["data"]
        uniqid = data["uniqid"]
        ptbk = get_ptbk(uniqid, cookie)
        result = decrypt(ptbk, all_data).split(",")
        result = [int(item) if item != "" else 0 for item in result]
        if len(result) == len(pd.date_range(start=start_date, end=end_date, freq="7D")):
            temp_df_7 = pd.DataFrame(
                [pd.date_range(start=start_date, end=end_date, freq="7D"), result],
                index=["date", word],
            ).T
            temp_df_7.index = pd.to_datetime(temp_df_7["date"])
            del temp_df_7["date"]
            return temp_df_7
        else:
            temp_df_1 = pd.DataFrame(
                [pd.date_range(start=start_date, end=end_date, freq="1D"), result],
                index=["date", word],
            ).T
            temp_df_1.index = pd.to_datetime(temp_df_1["date"])
            del temp_df_1["date"]
            return temp_df_1


def baidu_info_index(word, start_date, end_date, cookie):
    headers = {
        "Accept": "application/json, text/plain, */*",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9",
        "Cache-Control": "no-cache",
        "Cookie": cookie,
        "DNT": "1",
        "Host": "zhishu.baidu.com",
        "Pragma": "no-cache",
        "Proxy-Connection": "keep-alive",
        "Referer": "zhishu.baidu.com",
        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.90 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }
    session = requests.Session()
    session.headers.update(headers)
    with session.get(
        url=f"http://index.baidu.com/api/FeedSearchApi/getFeedIndex?word={word}&area=0&startDate={start_date}&endDate={end_date}"
    ) as response:
        data = response.json()["data"]
        all_data = data["index"][0]["data"]
        uniqid = data["uniqid"]
        ptbk = get_ptbk(uniqid, cookie)
        result = decrypt(ptbk, all_data).split(",")
        result = [int(item) if item != "" else 0 for item in result]
        if len(result) == len(pd.date_range(start=start_date, end=end_date, freq="7D")):
            temp_df_7 = pd.DataFrame(
                [pd.date_range(start=start_date, end=end_date, freq="7D"), result],
                index=["date", word],
            ).T
            temp_df_7.index = pd.to_datetime(temp_df_7["date"])
            del temp_df_7["date"]
            return temp_df_7
        else:
            temp_df_1 = pd.DataFrame(
                [pd.date_range(start=start_date, end=end_date, freq="1D"), result],
                index=["date", word],
            ).T
            temp_df_1.index = pd.to_datetime(temp_df_1["date"])
            del temp_df_1["date"]
            return temp_df_1


def baidu_media_index(word, start_date, end_date, cookie):
    headers = {
        "Accept": "application/json, text/plain, */*",
        "Accept-Encoding": "gzip, deflate",
        "Accept-Language": "zh-CN,zh;q=0.9",
        "Cache-Control": "no-cache",
        "Cookie": cookie,
        "DNT": "1",
        "Host": "zhishu.baidu.com",
        "Pragma": "no-cache",
        "Proxy-Connection": "keep-alive",
        "Referer": "zhishu.baidu.com",
        "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_6) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/75.0.3770.90 Safari/537.36",
        "X-Requested-With": "XMLHttpRequest",
    }
    session = requests.Session()
    session.headers.update(headers)
    with session.get(
        url=f"http://index.baidu.com/api/NewsApi/getNewsIndex?word={word}&area=0&startDate={start_date}&endDate={end_date}"
    ) as response:
        data = response.json()["data"]
        all_data = data["index"][0]["data"]
        uniqid = data["uniqid"]
        ptbk = get_ptbk(uniqid, cookie)
        result = decrypt(ptbk, all_data).split(",")
        result = ["0" if item == "" else item for item in result]
        result = [int(item) for item in result]
        if len(result) == len(pd.date_range(start=start_date, end=end_date, freq="7D")):
            temp_df_7 = pd.DataFrame(
                [pd.date_range(start=start_date, end=end_date, freq="7D"), result],
                index=["date", word],
            ).T
            temp_df_7.index = pd.to_datetime(temp_df_7["date"])
            del temp_df_7["date"]
            return temp_df_7
        else:
            temp_df_1 = pd.DataFrame(
                [pd.date_range(start=start_date, end=end_date, freq="1D"), result],
                index=["date", word],
            ).T
            temp_df_1.index = pd.to_datetime(temp_df_1["date"])
            del temp_df_1["date"]
            return temp_df_1


if __name__ == "__main__":
    cookie = "F7EB2ABF6DC23E3AE0D29AD77AC3A828; PSTM=1550065926; BAIDUID=7595D1FDD779944C2A288CBAD9865244:FG=1; H_WISE_SIDS=135670_136721_137754_138181_138497_114745_128149_139148_120168_138471_138878_137978_137690_131246_132551_118883_118873_118847_118829_118790_138165_138883_136431_138845_138697_136862_138146_138114_139172_139592_136196_137105_139273_139398_139691_133847_137735_138343_137467_138564_134256_131423_139397_139090_139246_137782_138657_136537_110085_137441_127969_139161_138837_139287_139407_127417_137186_136635_138426_139733_138941_139677_139221_138779; MCITY=-218%3A; bdshare_firstime=1580385892027; BDUSS=2JKVDg5clpLUGI2QzRnQmxtdGtad3VUSHVJN0VGQjNwSn5Ub2NSS1BRNnlsMTllRVFBQUFBJCQAAAAAAAAAAAEAAABU8PMTst24-dauw~cAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAAALIKOF6yCjheU; BDORZ=B490B5EBF6F3CD402E515D22BCDA1598; delPer=0; PSINO=6; Hm_lvt_d101ea4d2a5c67dab98251f0b5de24dc=1584712811; bdindexid=dmkg48p5ip10oj5u1cif5k06e7; H_PS_PSSID=30973_1432_31121_21101_20692_30908_30824_31086_26350_22157; Hm_lpvt_d101ea4d2a5c67dab98251f0b5de24dc=1584760723"
    data = baidu_search_index(
        word="口罩", start_date="2020-01-01", end_date="2020-02-14", cookie=cookie
    )
    print(data)
    data.dropna(inplace=True)
    data.plot()
    plt.show()
    data = baidu_info_index(
        word="疫情", start_date="2020-01-01", end_date="2020-02-14", cookie=cookie
    )
    print(data)
    data.dropna(inplace=True)
    data.plot()
    plt.show()
    data = baidu_media_index(
        word="武汉", start_date="2020-01-01", end_date="2020-02-14", cookie=cookie
    )
    print(data)
    data.dropna(inplace=True)
    data.plot()
    plt.show()





#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/27 0027
# @Author  : justin.郑 3907721@qq.com
# @File    : shibor.py
# @Desc    : 利率数据
# 上海银行间同业拆放利率（Shibor）数据接口
import json

import pandas as pd
import numpy as np
import requests

from gopup.economic import cons
from gopup.utils import date_utils as du


def shibor_data(year=None):
    """
    获取上海银行间同业拆放利率（Shibor）
    Parameters
    ------
      year:年份(int)

    Return
    ------
    date:日期
    ON:隔夜拆放利率
    1W:1周拆放利率
    2W:2周拆放利率
    1M:1个月拆放利率
    3M:3个月拆放利率
    6M:6个月拆放利率
    9M:9个月拆放利率
    1Y:1年拆放利率

    http://www.shibor.org/shibor/web/html/downLoad.html?nameNew=Historical_Shibor_Data_2019.xls&downLoadPath=data&nameOld=Shibor数据2019.xls&shiborSrc=http://www.shibor.org/shibor/
    """
    year = du.get_year() if year is None else year
    lab = cons.SHIBOR_TYPE['Shibor']
    try:
        url = cons.SHIBOR_DATA_URL % (cons.P_TYPE['http'], cons.DOMAINS['shibor'],
                                               cons.PAGES['dw'], 'Shibor',
                                               year, lab,
                                               year)
        herder = {
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
            "Accept-Language": "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3",
            "Accept-Encoding": "gzip, deflate",
            "Connection": "keep-alive"
        }

        r = requests.get(url, headers=herder)
        df = pd.read_excel(r.content)
        df.columns = cons.SHIBOR_COLS
        df['date'] = df['date'].map(lambda x: x.date())
        # if pd.__version__ < '0.21':
        #     df['date'] = df['date'].astype(np.datetime64)
        # else:
        #     df['date'] = df['date'].astype('datetime64[D]')
        return df
    except:
        return None


def shibor_quote_data(year=None):
    """
    获取Shibor银行报价数据
    Parameters
    ------
      year:年份(int)

    Return
    ------
    date:日期
    bank:报价银行名称
    ON:隔夜拆放利率
    ON_B:隔夜拆放买入价
    ON_A:隔夜拆放卖出价
    1W_B:1周买入
    1W_A:1周卖出
    2W_B:买入
    2W_A:卖出
    1M_B:买入
    1M_A:卖出
    3M_B:买入
    3M_A:卖出
    6M_B:买入
    6M_A:卖出
    9M_B:买入
    9M_A:卖出
    1Y_B:买入
    1Y_A:卖出
    """
    year = du.get_year() if year is None else year
    lab = cons.SHIBOR_TYPE['Quote']
    try:
        url = cons.SHIBOR_DATA_URL % (cons.P_TYPE['http'], cons.DOMAINS['shibor'],
                                      cons.PAGES['dw'], 'Quote',
                                      year, lab,
                                      year)
        herder = {
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
            "Accept-Language": "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3",
            "Accept-Encoding": "gzip, deflate",
            "Connection": "keep-alive"
        }

        r = requests.get(url, headers=herder)
        df = pd.read_excel(r.content)
        df.columns = cons.SHIBOR_Q_COLS
        df['date'] = df['date'].map(lambda x: x.date())
        # if pd.__version__ < '0.21':
        #     df['date'] = df['date'].astype(np.datetime64)
        # else:
        #     df['date'] = df['date'].astype('datetime64[D]')
        return df
    except:
        return None


def shibor_ma_data(year=None):
    """
    获取Shibor均值数据
    Parameters
    ------
      year:年份(int)

    Return
    ------
    date:日期
       其它分别为各周期5、10、20均价
    """
    year = du.get_year() if year is None else year
    lab = cons.SHIBOR_TYPE['Tendency']
    try:
        url = cons.SHIBOR_DATA_URL % (cons.P_TYPE['http'], cons.DOMAINS['shibor'],
                                               cons.PAGES['dw'], 'Shibor_Tendency',
                                               year, lab,
                                               year)
        herder = {
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
            "Accept-Language": "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3",
            "Accept-Encoding": "gzip, deflate",
            "Connection": "keep-alive"
        }

        r = requests.get(url, headers=herder)
        df = pd.read_excel(r.content)
        df.columns = cons.SHIBOR_MA_COLS

        df['date'] = df['date'].map(lambda x: x.date())
        if pd.__version__ < '0.21':
            df['date'] = df['date'].astype(np.datetime64)
        else:
            df['date'] = df['date'].astype('datetime64[D]')
        return df
    except:
        return None


def lpr_data(startDate, endDate):
    """
    获取贷款市场报价利率（LPR）
    Parameters
    ------
      startDate:起止日期(str)
      endDate:截止日期(str)

    Return
    ------
    showDateCN:日期
    1Y:1年贷款基础利率
    5Y:5年贷款基础利率
    """

    try:
        url = cons.LPR_DATA_URL

        herder = {
            "Accept": "text/html,application/xhtml+xml,application/xml;q=0.9,*/*;q=0.8",
            "Accept-Language": "zh-CN,zh;q=0.8,en-US;q=0.5,en;q=0.3",
            "Accept-Encoding": "gzip, deflate",
            "Connection": "keep-alive"
        }

        data = {
            "lang": "CN",
            "strStartDate": startDate,
            "strEndDate": endDate
        }

        r = requests.post(url, data=data, headers=herder)
        data_dict = json.loads(r.text)['records']
        df = pd.DataFrame(data_dict)

        return df
    except:
        return None

#
# def lpr_ma_data(year=None):
#     """
#     获取贷款基础利率均值数据
#     Parameters
#     ------
#       year:年份(int)
#
#     Return
#     ------
#     date:日期
#     1Y_5:5日均值
#     1Y_10:10日均值
#     1Y_20:20日均值
#     """
#     year = du.get_year() if year is None else year
#     lab = ct.SHIBOR_TYPE['LPR_Tendency']
#     lab = lab.encode('utf-8') if ct.PY3 else lab
#     try:
#         clt = Client(url=ct.SHIBOR_DATA_URL % (ct.P_TYPE['http'], ct.DOMAINS['shibor'],
#                                                ct.PAGES['dw'], 'LPR_Tendency',
#                                                year, lab,
#                                                year))
#         content = clt.gvalue()
#         df = pd.read_excel(StringIO(content), skiprows=[0])
#         df.columns = ct.LPR_MA_COLS
#         df['date'] = df['date'].map(lambda x: x.date())
#         if pd.__version__ < '0.21':
#             df['date'] = df['date'].astype(np.datetime64)
#         else:
#             df['date'] = df['date'].astype('datetime64[D]')
#         return df
#     except:
#         return None


if __name__ == "__main__":
    lpr_data(startDate="2020-09-01", endDate="2020-09-30")
 




#!/usr/bin/env python
# -*- coding: utf-8 -*-
# @Time    : 2020/3/20 0020
# @Author  : justin.郑 3907721@qq.com
# @File    : my_fun.py
# @Desc    : 
 

def gopup_test():
    return "测试成功"


def add_sum(a):
    '''
    计算从1+到a
    :param a:
    :return:
    '''
    res = False
    if type(a) == int:
        sum = 0
        for i in range(a + 1):  # 实际遍历到n
            sum += i
        res = True
    else:
        sum = '{0}不是整型，无法计算'.format(a)
    return res, sum


if __name__ == "__main__":
    tmp = add_sum(12)
    print(tmp)




"""
GoPup 是基于 Python 的开源金融数据接口库, 目的是实现对金融产品和另类数据从数据采集, 数据清洗到数据下载的工具, 满足金融数据科学家, 数据科学爱好者在数据获取方面的需求.
它的特点是利用 GoPup 获取的是基于可信任数据源发布的原始数据, 广大数据科学家可以利用原始数据进行再加工, 从而得出科学的结论.
"""


"""
谷歌指数
"""
# from gopup.index.index_google import google_index

"""
百度指数
"""
from gopup.index.index_baidu import (
    baidu_search_index,
    baidu_info_index,
    baidu_media_index,
)

"""
微博指数
"""
from gopup.index.index_weibo import weibo_index


"""
百度迁徙地图接口
"""
from gopup.event.area_baidu import migration_area_baidu


"""
新型冠状病毒接口
"""
from gopup.event.covid import (
    covid_163,
    covid_dxy,
    covid_baidu,
    covid_hist_city,
    covid_hist_province,
)

"""
中国宏观数据
"""
from gopup.economic.marco_cn import (
    marco_cmlrd, get_gdp_year, get_gdp_quarter, get_gdp_for,
    get_gdp_pull, get_gdp_contrib, get_cpi, get_ppi, get_deposit_rate,
    get_loan_rate, get_rrr, get_money_supply, get_money_supply_bal,
    get_gold_and_foreign_reserves
)


"""
利率数据
"""
from gopup.economic.shibor import (shibor_data, shibor_quote_data,
                                  shibor_ma_data, lpr_data)

# from gopup.my_fun import (gopup_test, add_sum)


"""
达人数据
"""
# from gopup.mcn.star import (star_hot_list, star_market_list)
